@@ -65,7 +65,7 @@ class CMSMailer extends CMSModule
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '2.0.2';
+    return '5.2.2';
   }
 
 
@@ -246,7 +246,7 @@ class CMSMailer extends CMSModule
   function DoAction($action, $id, $params, $returnid=-1)
   {
     $gCms = cmsms();
-    $smarty =& $gCms->GetSmarty();
+    $smarty = $gCms->GetSmarty();
     $smarty->assign_by_ref('mod',$this);
 
     switch ($action)
@@ -291,8 +291,8 @@ class CMSMailer extends CMSModule
       {
 	$obj = new StdClass;
 	$obj->priority = 1;
-	$link = 'moduleinterface.php?'.CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY].'&amp;module=CMSMailer';
-	$obj->html = lang('warning_mail_settings', $link).'&nbsp;'.$this->Lang('warning_cron_updated');
+	$obj->link = $this->create_url('m1_','defaultadmin');
+	$obj->html = lang('warning_mail_settings', $obj->link).'&nbsp;'.$this->Lang('warning_cron_updated');
 	
 	return $obj;
       }
@@ -319,13 +319,14 @@ class CMSMailer extends CMSModule
     $this->the_mailer->SMTPAuth = $this->GetPreference('smtpauth');
     $this->the_mailer->Username = $this->GetPreference('username');
     $this->the_mailer->Password = $this->GetPreference('password');
+    $this->the_mailer->SMTPSecure = $this->GetPreference('secure');
+    $this->the_mailer->ErrorInfo = '';
     $this->the_mailer->ClearAddresses();
     $this->the_mailer->ClearAttachments();
     $this->the_mailer->ClearCustomHeaders();
     $this->the_mailer->ClearBCCs();
     $this->the_mailer->ClearCCs();
     $this->the_mailer->ClearReplyTos();
-    $this->the_mailer->SMTPSecure = $this->GetPreference('secure');
     $charset = $this->GetPreference('charset','utf-8');
     if( $charset == '' ) $charset = 'utf-8';
     $this->SetCharSet($charset);
@@ -338,96 +339,52 @@ class CMSMailer extends CMSModule
    ---------------------------------------------------------*/
   function _SetAdminPrefs($id, &$params, $returnid )
   {
-    if( !$this->CheckPermission('Modify Site Preferences') )
-      return;
+    if( !$this->CheckPermission('Modify Site Preferences') ) return;
 
     set_site_preference('mail_is_set',1);
 
-    if( isset( $params['input_mailer'] ) )
-      {
-	$this->SetPreference('mailer',$params['input_mailer']);
-      }
+    if( isset( $params['input_mailer'] ) ) $this->SetPreference('mailer',$params['input_mailer']);
+    if( isset( $params['input_host'] ) ) $this->SetPreference('host',$params['input_host']);
+    if( isset( $params['input_secure'] ) ) $this->SetPreference('secure',$params['input_secure']);
+    if( isset( $params['input_port'] ) ) $this->SetPreference('port',$params['input_port']);
+    if( isset( $params['input_from'] ) ) $this->SetPreference('from',$params['input_from']);
+    if( isset( $params['input_fromuser'] ) ) $this->SetPreference('fromuser',$params['input_fromuser']);
+    if( isset( $params['input_sendmail'] ) ) $this->SetPreference('sendmail',$params['input_sendmail']);
+    if( isset( $params['input_timeout'] ) ) $this->SetPreference('timeout',$params['input_timeout']);
+    if( isset( $params['input_charset'] ) ) $this->SetPreference('charset',trim($params['input_charset']));
 
-    if( isset( $params['input_host'] ) )
-      {
-	$this->SetPreference('host',$params['input_host']);
-      }
+    if( isset( $params['input_smtpauth'] ) ) {
+      $this->SetPreference('smtpauth',$params['input_smtpauth']);
+    }
+    else {
+      $this->SetPreference('smtpauth',0);
+    }
 
-    if( isset( $params['input_secure'] ) )
-      {
-	$this->SetPreference('secure',$params['input_secure']);
-      }
+    if( isset( $params['input_username'] ) && $params['input_username'] != '' ) {
+      $this->SetPreference('username',$params['input_username']);
+    }
 
-    if( isset( $params['input_port'] ) )
-      {
-	$this->SetPreference('port',$params['input_port']);
-      }
-
-    if( isset( $params['input_from'] ) )
-      {
-	$this->SetPreference('from',$params['input_from']);
-      }
-
-    if( isset( $params['input_fromuser'] ) )
-      {
-	$this->SetPreference('fromuser',$params['input_fromuser']);
-      }
-
-    if( isset( $params['input_sendmail'] ) )
-      {
-	$this->SetPreference('sendmail',$params['input_sendmail']);
-      }
-
-    if( isset( $params['input_timeout'] ) )
-      {
-	$this->SetPreference('timeout',$params['input_timeout']);
-      }
-
-    if( isset( $params['input_smtpauth'] ) )
-      {
-	$this->SetPreference('smtpauth',$params['input_smtpauth']);
-      }
-    else
-      {
-	$this->SetPreference('smtpauth',0);
-      }
-
-    if( isset( $params['input_username'] ) )
-      {
-	$this->SetPreference('username',$params['input_username']);
-      }
-
-    if( isset( $params['input_password'] ) )
-      {
-	$this->SetPreference('password',$params['input_password']);
-      }
-
-    if( isset( $params['input_charset'] ) )
-      {
-	$this->SetPreference('charset',trim($params['input_charset']));
-      }
+    if( isset( $params['input_password'] ) && $params['input_password'] != '' ) {
+      $this->SetPreference('password',$params['input_password']);
+    }
 
     $this->reset();
 
-    if( isset( $params['sendtest'] ) )
-      {
-	// here we're gonna send a nice, hard coded test message
-	if( !isset( $params['input_testaddress'] ) || trim($params['input_testaddress']) == '' )
-	  {
-	    $this->_DisplayErrorPage( $id, $params, $returnid, 
-				      $this->Lang('error_notestaddress'));
-	    return;
-	  }
-	else
-	  {
-	    $this->AddAddress( $params['input_testaddress'] );
-	    $this->IsHTML(true);
-	    $this->SetBody( $this->Lang('testbody'));
-	    $this->SetSubject( $this->Lang('testsubject'));
-	    $this->Send();
-	    $this->reset(); // yes, another reset
-	  }
+    if( isset( $params['sendtest'] ) ) {
+      // here we're gonna send a nice, hard coded test message
+      if( !isset( $params['input_testaddress'] ) || trim($params['input_testaddress']) == '' ) {
+	$this->_DisplayErrorPage( $id, $params, $returnid, $this->Lang('error_notestaddress'));
+	return;
       }
+      else {
+	$this->AddAddress( $params['input_testaddress'] );
+	$this->IsHTML(true);
+	$this->SetBody( $this->Lang('testbody'));
+	$this->SetSubject( $this->Lang('testsubject'));
+	$this->Send();
+	$this->reset(); // yes, another reset
+      }
+    }
 
     $this->Redirect( $id, 'defaultadmin', $returnid, $params );
   }
