@@ -1,4 +1,10 @@
 <?php
+$lang['help_idlist'] = 'Applicable only to the default action (summary view).  This parameter accepts a comma separated list of numeric article ids and allows further filtering articles to only the article ids specified.  The actual list of articles output is still subject to article status, expiry date, and other parameters.';
+$lang['error_nooptions'] = 'No options specified for field definition';
+$lang['dropdown'] = 'Dropdown';
+$lang['info_public'] = 'Only Public fields are available for frontend editing, or for display in summary or detail views.';
+$lang['info_expired_viewable'] = 'If enabled, expired articles can be viewed in detail mode (this is reproducing older functionality).  the showall parameter can be used on the URL (when not using pretty urls) to also indicate that expired articles can be viewed';
+$lang['expired_viewable'] = 'Expired articles can be viewed in the detail view';
 $lang['error_insufficientparams'] = 'Insufficient (or empty) parameters';
 $lang['error_duplicatename'] = 'An item with that name already exists';
 $lang['detail_page'] = 'Detail Page';
@@ -120,6 +126,7 @@ $lang['addarticle'] = 'Add Article';
 $lang['articleadded'] = 'The article was successfully added.';
 $lang['articleupdated'] = 'The article was successfully updated.';
 $lang['articledeleted'] = 'The article was successfully deleted.';
+$lang['articlesubmitted'] = 'The article was successfully submitted.';
 $lang['addcategory'] = 'Add Category';
 $lang['categoryadded'] = 'The category was successfully added.';
 $lang['categoryupdated'] = 'The category was successfully updated.';
@@ -177,6 +184,7 @@ $lang['sortascending'] = 'Sort Ascending';
 $lang['startdate'] = 'Start Date';
 $lang['startoffset'] = 'Start displaying at the nth item';
 $lang['startrequiresend'] = 'Entering a start date requires an end date also';
+$lang['apply'] = 'Apply';
 $lang['submit'] = 'Submit';
 $lang['summary'] = 'Summary';
 $lang['summarytemplate'] = 'Summary Templates';
@@ -189,62 +197,63 @@ $lang['eventdesc-NewsArticleAdded'] = 'Sent when an article is added.';
 $lang['eventhelp-NewsArticleAdded'] = '<p>Sent when an article is added.</p>
 <h4>Parameters</h4>
 <ul>
-<li>\"news_id\" - Id of the news article</li>
-<li>\"category_id\" - Id of the category for this article</li>
-<li>\"title\" - Title of the article</li>
-<li>\"content\" - Content of the article</li>
-<li>\"summary\" - Summary of the article</li>
-<li>\"status\" - Status of the article ("draft" or "publish")</li>
-<li>\"start_time\" - Date the article should start being displayed</li>
-<li>\"end_time\" - Date the article should stop being displayed</li>
-<li>\"useexp\" - Whether the expiration date should be ignored or not</li>
+<li>"news_id" - Id of the news article</li>
+<li>"category_id" - Id of the category for this article</li>
+<li>"title" - Title of the article</li>
+<li>"content" - Content of the article</li>
+<li>"summary" - Summary of the article</li>
+<li>"status" - Status of the article ("draft" or "publish")</li>
+<li>"start_time" - Date the article should start being displayed</li>
+<li>"end_time" - Date the article should stop being displayed</li>
+<li>"useexp" - Whether the expiration date should be ignored or not</li>
 </ul>
 ';
 $lang['eventdesc-NewsArticleEdited'] = 'Sent when an article is edited.';
 $lang['eventhelp-NewsArticleEdited'] = '<p>Sent when an article is edited.</p>
 <h4>Parameters</h4>
 <ul>
-<li>\"news_id\" - Id of the news article</li>
-<li>\"category_id\" - Id of the category for this article</li>
-<li>\"title\" - Title of the article</li>
-<li>\"content\" - Content of the article</li>
-<li>\"summary\" - Summary of the article</li>
-<li>\"status\" - Status of the article ("draft" or "publish")</li>
-<li>\"start_time\" - Date the article should start being displayed</li>
-<li>\"end_time\" - Date the article should stop being displayed</li>
-<li>\"useexp\" - Whether the expiration date should be ignored or not</li>
+<li>"news_id" - Id of the news article</li>
+<li>"category_id" - Id of the category for this article</li>
+<li>"title" - Title of the article</li>
+<li>"content" - Content of the article</li>
+<li>"summary" - Summary of the article</li>
+<li>"status" - Status of the article ("draft" or "publish")</li>
+<li>"start_time" - Date the article should start being displayed</li>
+<li>"end_time" - Date the article should stop being displayed</li>
+<li>"useexp" - Whether the expiration date should be ignored or not</li>
 </ul>
+<p><strong>Note:</strong> Not all parameters may be present when this event is sent.</p>
 ';
 $lang['eventdesc-NewsArticleDeleted'] = 'Sent when an article is deleted.';
 $lang['eventhelp-NewsArticleDeleted'] = '<p>Sent when an article is deleted.</p>
 <h4>Parameters</h4>
 <ul>
-<li>\"news_id\" - Id of the news article</li>
+<li>"news_id" - Id of the news article</li>
 </ul>
 ';
 $lang['eventdesc-NewsCategoryAdded'] = 'Sent when a category is added.';
 $lang['eventhelp-NewsCategoryAdded'] = '<p>Sent when a category is added.</p>
 <h4>Parameters</h4>
 <ul>
-<li>\"category_id\" - Id of the news category</li>
-<li>\"name\" - Name of the news category</li>
+<li>"category_id" - Id of the news category</li>
+<li>"name" - Name of the news category</li>
 </ul>
 ';
 $lang['eventdesc-NewsCategoryEdited'] = 'Sent when a category is edited.';
 $lang['eventhelp-NewsCategoryEdited'] = '<p>Sent when a category is edited.</p>
 <h4>Parameters</h4>
 <ul>
-<li>\"category_id\" - Id of the news category</li>
-<li>\"name\" - Name of the news category</li>
-<li>\"origname\" - The original name of the news category</li>
+<li>"category_id" - Id of the news category</li>
+<li>"name" - Name of the news category</li>
+<li>"origname" - The original name of the news category</li>
 </ul>
 ';
 $lang['eventdesc-NewsCategoryDeleted'] = 'Sent when a category is deleted.';
 $lang['eventhelp-NewsCategoryDeleted'] = '<p>Sent when a category is deleted.</p>
 <h4>Parameters</h4>
 <ul>
-<li>\"category_id\" - Id of the deleted category </li>
-<li>\"name\" - Name of the deleted category</li>
+<li>"category_id" - Id of the deleted category </li>
+<li>"name" - Name of the deleted category</li>
 </ul>
 ';
 
@@ -267,7 +276,7 @@ $lang['helpaction'] = <<<EOT
 <ul>
 <li>&quot;detail&quot; - to display a specified articleid in detail mode.</li>
 <li>&quot;default&quot; - to display the summary view</li>
-<li>&quot;fesubmit&quot; - to display the frontend form for allowing users to submit news articles on the front end. Add the <code>{cms_init_editor}</code> tag in the metadata section to initialize the selected wysiwyg editor. (Site Admin >> Global Settings)</li>
+<li>&quot;fesubmit&quot; - <strong>Deprecated</strong> to display the frontend form for allowing users to submit news articles on the front end. Add the <code>{cms_init_editor}</code> tag in the metadata section to initialize the selected wysiwyg editor. (Site Admin >> Global Settings)</li>
 <li>&quot;browsecat&quot; - to display a browseable category list.</li>
 </ul>
 EOT;
