@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-function smarty_cms_function_redirect_page($params, &$smarty)
+function smarty_function_redirect_page($params, &$template)
 {
   if( isset($params['page']) ) redirect_to_alias(trim($params['page']));
 }
