@@ -41,6 +41,8 @@ class ContentOperations
 {
 	protected function __construct() {}
 	private $_content_types;
+	private $_default_content_id;
+	private $_quickfind;
 	private static $_instance;
 
 	public static function &get_instance()
@@ -72,7 +74,7 @@ class ContentOperations
 
 
 	/**
-	 * Given an array of content_type and seralized_content, reconstructs a 
+	 * Given an array of content_type and seralized_content, reconstructs a
 	 * content object.  It will handled loading the content type if it hasn't
 	 * already been loaded.
 	 *
@@ -104,19 +106,16 @@ class ContentOperations
 	 */
 	final public function LoadContentType($type)
 	{
-		if( is_object($type) && $type instanceof CmsContentTypePlaceHolder ) 
-			{
-				$type = $type->type;
-			}
+		if( is_object($type) && $type instanceof CmsContentTypePlaceHolder ) {
+			$type = $type->type;
+		}
 
 		$ctph = $this->_get_content_type($type);
-		if( is_object($ctph) )
-			{
-				if( !class_exists( $ctph->class ) && file_exists( $ctph->filename ) )
-					{
-						include_once( $ctph->filename );
-					}
+		if( is_object($ctph) ) {
+			if( !class_exists( $ctph->class ) && file_exists( $ctph->filename ) ) {
+				include_once( $ctph->filename );
 			}
+		}
 
 		return $ctph;
 	}
@@ -134,21 +133,19 @@ class ContentOperations
 	 */
 	public function &CreateNewContent($type)
 	{
-		if( is_object($type) && $type instanceof CmsContentTypePlaceHolder ) 
-			{
-				$type = $type->type;
-			}
+		if( is_object($type) && $type instanceof CmsContentTypePlaceHolder ) {
+			$type = $type->type;
+		}
 		$result = NULL;
 
 		$ctph = $this->LoadContentType($type);
-		if( class_exists($ctph->class) )
-			{
-				$result = new $ctph->class;
-			}
+		if( is_object($ctph) && class_exists($ctph->class) ) {
+			$result = new $ctph->class;
+		}
 		return $result;
 	}
 
-	
+
     /**
      * Given a content id, load and return the loaded content object.
      *
@@ -252,11 +249,9 @@ class ContentOperations
 	 */
 	function GetDefaultContent()
 	{
+		if( $this->_default_content_id ) return $this->_default_content_id;
+
 		$gCms = cmsms();
-	  if( isset($gCms->variables['default_content_id']) )
-	    {
-	      return $gCms->variables['default_content_id'];
-	    }
 		$db = $gCms->GetDb();
 
 		$result = -1;
@@ -278,7 +273,7 @@ class ContentOperations
 			}
 		}
 
-		$gCms->variables['default_content_id'] = $result;
+		$this->_default_content_id = $result;
 		return $result;
 	}
 
@@ -409,7 +404,7 @@ class ContentOperations
 			if( $tmp )
 				$disallowed_a = explode(',',$tmp);
 		}
-			
+
 		$this->_get_content_types();
 		$types = $this->_content_types;
 		if ( isset($types) )
@@ -420,7 +415,7 @@ class ContentOperations
 					global $CMS_ADMIN_PAGE;
 					if( !isset($obj->friendlyname) && isset($obj->friendlyname_key) && isset($CMS_ADMIN_PAGE) )
 						{
-							$txt = lang($obj->friendlyname_key); 
+							$txt = lang($obj->friendlyname_key);
 							$obj->friendlyname = $txt;
 						}
 					if( !$allowed || count($disallowed_a) == 0 || !in_array($obj->type,$disallowed_a) )
@@ -517,18 +512,18 @@ class ContentOperations
 		    $this->SetHierarchyPosition($dbresult->fields['content_id']);
 			$dbresult->MoveNext();
 		}
-		
+
 		if ($dbresult) $dbresult->Close();
 		cms_content_cache::clear();
 	}
 
-	
+
 	/**
 	 * Loads a set of content objects into the cached tree.
 	 *
 	 * @param boolean $loadprops If true, load the properties of those content objects
 	 * @param boolean $onlyexpanded Not implemented
-	 * @param boolean $loadcontent If false, only create the nodes in the tree, 
+	 * @param boolean $loadcontent If false, only create the nodes in the tree,
 	 *                             don't load the content objects
 	 * @return mixed The cached tree of content
 	 */
@@ -545,7 +540,7 @@ class ContentOperations
 		if (file_exists($cachefilename))
 		{
 			$last_modified = cms_utils::get_app_data('last_content_modification');
-			if( !$last_modified );
+			if( $last_modified <= 0 );
 			{
 				$query = 'SELECT modified_date FROM '.cms_db_prefix().'content ORDER BY modified_date DESC';
 				$val = $db->GetOne($query);
@@ -554,21 +549,20 @@ class ContentOperations
 			}
 			if ($last_modified > 0 && $last_modified < filemtime($cachefilename))
 			{
-				debug_buffer('file needs loading');
-				
+				debug_buffer('Content tree file needs loading');
+
 				$handle = fopen($cachefilename, "r");
 				$data = fread($handle, filesize($cachefilename));
 				fclose($handle);
-				
+
 				$tree = unserialize(substr($data, 16));
-				
+
 				if (strtolower(get_class($tree)) == 'cms_content_tree')
 				{
 					$loadedcache = true;
 				}
 				else
 				{
-					die('problem loading cache');
 					$loadedcache = false;
 				}
 			}
@@ -576,19 +570,9 @@ class ContentOperations
 
 		if (!$loadedcache)
 		{
-			$query = "SELECT id_hierarchy,content_alias FROM ".cms_db_prefix()."content ORDER BY hierarchy";
-			$dbresult = $db->Execute($query);
-			$nodes = array();
-			if ($dbresult && $dbresult->RecordCount() > 0)
-			{
-				while ($row = $dbresult->FetchRow())
-				{
-					$nodes[] = $row['id_hierarchy'].','.$row['content_alias'];
-				}
-				$dbresult->Close();
-			}
-
 			debug_buffer('', 'Start Loading Children into Tree');
+			$query = 'SELECT content_id,parent_id,content_alias FROM '.cms_db_prefix().'content ORDER BY parent_id,item_order';
+			$nodes = $db->GetArray($query);
 			$tree = cms_tree_operations::load_from_list($nodes);
 			debug_buffer('', 'End Loading Children into Tree');
 		}
@@ -609,100 +593,104 @@ class ContentOperations
 		return $tree;
 	}
 
-	
+
 	/**
 	 * Loads additional, active children into a given tree object
 	 *
 	 * @param integer $id The parent of the content objects to load into the tree
 	 * @param boolean $loadprops If true, load the properties of all loaded content objects
 	 * @param boolean $all If true, load all content objects, even inactive ones.
+	 * @param array   (optional) array of explicit content ids to load
 	 * @return void
 	 * @author Ted Kulp
 	 */
 	function LoadChildren($id, $loadprops = false, $all = false, $explicit_ids = array() )
-	{	
+	{
 		$gCms = cmsms();
 		$db = $gCms->GetDb();
 
 		$contentrows = '';
 		if( is_array($explicit_ids) && count($explicit_ids) )
 		{
+			$loaded_ids = cms_content_cache::get_loaded_page_ids();
+			if( is_array($loaded_ids) && count($loaded_ids) ) {
+				$tmp = array();
+				foreach( $explicit_ids as $one ) {
+					if( in_array($one,$loaded_ids) ) continue;
+					$tmp[] = $one;
+				}
+				if( count($tmp) == 0 ) return;
+				$explicit_ids = $tmp;
+			}
+
 			$expr = 'content_id IN ('.implode(',',$explicit_ids).')';
 			if( !$all ) $expr .= ' AND active = 1';
 
-			$query = 'SELECT * FROM '.cms_db_prefix().'content WHERE '.$expr.' ORDER BY hierarchy';
+			// note, this is mysql specific...
+			$query = 'SELECT * FROM '.cms_db_prefix().'content FORCE INDEX ('.cms_db_prefix().'index_content_by_idhier) WHERE '.$expr.' ORDER BY hierarchy';
 			$contentrows = $db->GetArray($query);
 		}
-		else 
+		else
 		{
 			if( !$id ) { $id = -1; }
 			// get the content rows
 			$query = "SELECT * FROM ".cms_db_prefix()."content WHERE parent_id = ? AND active = 1 ORDER BY hierarchy";
-			if( $all )
-				$query = "SELECT * FROM ".cms_db_prefix()."content WHERE parent_id = ? ORDER BY hierarchy";
+			if( $all ) $query = "SELECT * FROM ".cms_db_prefix()."content WHERE parent_id = ? ORDER BY hierarchy";
 			$contentrows = $db->GetArray($query, array($id));
 		}
-		$contentprops = '';
+
+		$contentprops = null;
 
 		// get the content ids from the returned data
-		if( $loadprops )
-		  {
+		if( $loadprops ) {
 		    $child_ids = array();
-		    for( $i = 0; $i < count($contentrows); $i++ )
-		      {
-				  $child_ids[] = $contentrows[$i]['content_id'];
-		      }
-		    
-		    // get all the properties for the child_ids
-		    $query = 'SELECT * FROM '.cms_db_prefix().'content_props WHERE content_id IN ('.implode(',',$child_ids).') ORDER BY content_id';
-		    $tmp = $db->GetArray($query);
+		    for( $i = 0; $i < count($contentrows); $i++ ) {
+				$child_ids[] = $contentrows[$i]['content_id'];
+			}
+
+			$tmp = null;
+			if( count($child_ids) ) {
+				// get all the properties for the child_ids
+				$query = 'SELECT * FROM '.cms_db_prefix().'content_props WHERE content_id IN ('.implode(',',$child_ids).') ORDER BY content_id';
+				$tmp = $db->GetArray($query);
+			}
 
 		    // re-organize the tmp data into a hash of arrays of properties for each content id.
-		    if( $tmp )
-		      {
-				  $contentprops = array();
-				  for( $i = 0; $i < count($contentrows); $i++ )
-					  {
-						  $content_id = $contentrows[$i]['content_id'];
-						  $t2 = array();
-						  for( $j = 0; $j < count($tmp); $j++ )
-							  {
-								  if( $tmp[$j]['content_id'] == $content_id )
-									  {
-										  $t2[] = $tmp[$j];
-									  }
-							  }
-						  $contentprops[$content_id] = $t2;
-					  }
-		      }
-		  }
-		
+		    if( $tmp ) {
+				$contentprops = array();
+				for( $i = 0; $i < count($tmp); $i++ ) {
+					$content_id = $tmp[$i]['content_id'];
+					if( in_array($content_id,$child_ids) ) {
+						if( !isset($contentprops[$content_id]) ) $contentprops[$content_id] = array();
+						$contentprops[$content_id][] = $tmp[$i];
+					}
+				}
+				unset($tmp);
+			}
+		}
+
 		// build the content objects
-		for( $i = 0; $i < count($contentrows); $i++ )
-		  {
+		for( $i = 0; $i < count($contentrows); $i++ ) {
 		    $row = $contentrows[$i];
 		    $id = $row['content_id'];
 
 		    if (!in_array($row['type'], array_keys($this->ListContentTypes()))) continue;
 		    $contentobj = $this->CreateNewContent($row['type']);
 
-		    if ($contentobj)
-		      {
-				  $contentobj->LoadFromData($row, false);
-				  if( $loadprops && $contentprops && isset($contentprops[$id]) )
-					  {
-						  // load the properties from local cache.
-						  $props = $contentprops[$id];
-						  foreach( $props as $oneprop )
-							  {
-								  $contentobj->SetPropertyValueNoLoad($oneprop['prop_name'],$oneprop['content']);
-							  }
-					  }
-				  
-				  // cache the content objects
-				  cms_content_cache::add_content($id,$contentobj->Alias(),$contentobj);
-		      }
-		  }
+		    if ($contentobj) {
+				$contentobj->LoadFromData($row, false);
+				if( $loadprops && $contentprops && isset($contentprops[$id]) ) {
+					// load the properties from local cache.
+					$props = $contentprops[$id];
+					foreach( $props as $oneprop ) {
+						$contentobj->SetPropertyValueNoLoad($oneprop['prop_name'],$oneprop['content']);
+					}
+				}
+
+				// cache the content objects
+				cms_content_cache::add_content($id,$contentobj->Alias(),$contentobj);
+			}
+		}
 	}
 
 	/**
@@ -717,21 +705,97 @@ class ContentOperations
 		$db = $gCms->GetDb();
 		$query = "SELECT content_id FROM ".cms_db_prefix()."content WHERE default_content=1";
 		$old_id = $db->GetOne($query);
-		if (isset($old_id)) 
+		if (isset($old_id))
 		{
 			$one = new Content();
 			$one->LoadFromId($old_id);
 			$one->SetDefaultContent(false);
-			debug_buffer('save from ' . __LINE__);
 			$one->Save();
 		}
 		$one = new Content();
 		$one->LoadFromId($id);
 		$one->SetDefaultContent(true);
-		debug_buffer('save from ' . __LINE__);
 		$one->Save();
 	}
 
+	public function LoadAllContent($loadprops = FALSE,$inactive = FALSE,$showinmenu = FALSE)
+	{
+		static $_loaded = 0;
+		if( $_loaded == 1 ) return;
+		$_loaded = 1;
+
+		$db = cmsms()->GetDb();
+
+		$expr = array();
+		$parms = array();
+		if( !$inactive ) {
+			$expr[] = 'active = ?';
+			$parms[] = 1;
+		}
+		if( $showinmenu ) {
+			$expr[] = 'show_in_menu = ?';
+			$parms[] = 1;
+		}
+
+		$loaded_ids = cms_content_cache::get_loaded_page_ids();
+		if( is_array($loaded_ids) && count($loaded_ids) ) {
+			$expr[] = 'content_id NOT IN ('.implode(',',$loaded_ids).')';
+		}
+
+		$query = 'SELECT * FROM '.cms_db_prefix().'content FORCE INDEX ('.cms_db_prefix().'index_content_by_idhier)';
+		if( count($expr) ) $query .= ' WHERE '.implode(' AND ',$expr);
+		$contentrows = $db->GetArray($query,$parms);
+
+		if( $loadprops ) {
+		    $child_ids = array();
+		    for( $i = 0; $i < count($contentrows); $i++ ) {
+				$child_ids[] = $contentrows[$i]['content_id'];
+			}
+
+			$tmp = null;
+			if( count($child_ids) ) {
+				// get all the properties for the child_ids
+				$query = 'SELECT * FROM '.cms_db_prefix().'content_props WHERE content_id IN ('.implode(',',$child_ids).') ORDER BY content_id';
+				$tmp = $db->GetArray($query);
+			}
+
+		    // re-organize the tmp data into a hash of arrays of properties for each content id.
+		    if( $tmp ) {
+				$contentprops = array();
+				for( $i = 0; $i < count($tmp); $i++ ) {
+					$content_id = $tmp[$i]['content_id'];
+					if( in_array($content_id,$child_ids) ) {
+						if( !isset($contentprops[$content_id]) ) $contentprops[$content_id] = array();
+						$contentprops[$content_id][] = $tmp[$i];
+					}
+				}
+				unset($tmp);
+			}
+		}
+
+		// build the content objects
+		for( $i = 0; $i < count($contentrows); $i++ ) {
+		    $row = $contentrows[$i];
+		    $id = $row['content_id'];
+
+		    if (!in_array($row['type'], array_keys($this->ListContentTypes()))) continue;
+		    $contentobj = $this->CreateNewContent($row['type']);
+
+		    if ($contentobj) {
+				$contentobj->LoadFromData($row, false);
+				if( $loadprops && $contentprops && isset($contentprops[$id]) ) {
+					// load the properties from local cache.
+					$props = $contentprops[$id];
+					foreach( $props as $oneprop ) {
+						$contentobj->SetPropertyValueNoLoad($oneprop['prop_name'],$oneprop['content']);
+					}
+				}
+
+				// cache the content objects
+				cms_content_cache::add_content($id,$contentobj->Alias(),$contentobj);
+			}
+		}
+	}
 
 	/**
 	 * Returns an array of all content objects in the system, active or not.
@@ -746,11 +810,12 @@ class ContentOperations
 		$gCms = cmsms();
 		$tree = $gCms->GetHierarchyManager();
 		$list = $tree->getFlatList();
+		$this->LoadAllContent($loadprops);
 
 		$output = array();
 		foreach( $list as &$one )
 		{
-			$tmp = $one->GetContent();
+			$tmp = $one->GetContent(false,true,true);
 			if( is_object($tmp) )
 				$output[] = $tmp;
 		}
@@ -773,16 +838,20 @@ class ContentOperations
 	 * @param boolean $use_perms If true, checks authorship permissions on pages and only shows those the current
 	 *                user has access to.
 	 * @param boolean $ignore_current Ignores the value of $current totally by not marking any items as invalid.
-	 * @param boolean $allow_all If true, show all items, even if the content object 
+	 * @param boolean $allow_all If true, show all items, even if the content object
 	 *                           doesn't have a valid link. Defaults to false.
-	 * @param boolean $use_name if true use Name() else use MenuText() Defaults to true.
+	 * @param boolean $use_name if true use Name() else use MenuText() Defaults to using the system preference.
 	 * @return string The html dropdown of the hierarchy
 	 */
-	function CreateHierarchyDropdown($current = '', $parent = '', $name = 'parent_id', $allowcurrent = 0, $use_perms = 0, $ignore_current = 0, $allow_all = false, $use_name = true)
+	function CreateHierarchyDropdown($current = '', $parent = '', $name = 'parent_id', $allowcurrent = 0, $use_perms = 0, $ignore_current = 0, $allow_all = false, $use_name = null)
 	{
 		$result = '';
 		$userid = -1;
 
+		if( is_null($use_name) ) {
+			$use_name = get_site_preference('listcontent_showtitle',true);
+		}
+
 		$allcontent = $this->GetAllContent(false);
 
 		if ($allcontent !== FALSE && count($allcontent) > 0)
@@ -791,7 +860,7 @@ class ContentOperations
 			  {
 			    $userid = get_userid();
 			  }
-			if( ($userid > 0 && check_permission($userid,'Manage All Content')) || 
+			if( ($userid > 0 && check_permission($userid,'Manage All Content')) ||
 			    $userid == -1 ||
 			    $parent == -1 )
 			  {
@@ -808,7 +877,7 @@ class ContentOperations
 			      // Grab hierarchy just in case we need to check children
 			      // (which will always be after)
 			      $curhierarchy = $one->Hierarchy();
-			      
+
 			      if( !$allowcurrent )
 				{
 				  // Then jump out.  We don't want ourselves in the list.
@@ -826,8 +895,8 @@ class ContentOperations
 
 			  // If it's a child of the current, we don't want to show it as it
 			  // could cause a deadlock.
-			  if (!$allowcurrent && 
-			      $curhierarchy != '' && 
+			  if (!$allowcurrent &&
+			      $curhierarchy != '' &&
 			      strstr($one->Hierarchy() . '.', $curhierarchy . '.') == $one->Hierarchy() . '.')
 			    {
 			      continue;
@@ -837,18 +906,18 @@ class ContentOperations
                           // has write access... or is an admin user... or has appropriate permission.
 			  if( $userid > 0 && $one->Id() != $parent)
 			    {
-			      if( !check_permission($userid,'Manage All Content') && 
+			      if( !check_permission($userid,'Manage All Content') &&
 				  !check_authorship($userid,$one->Id()) )
 				{
 				  continue;
 				}
-			    }				
+			    }
 
 			  // Don't include content types that do not want children either...
 			  if (!$one->WantsChildren()) continue;
 			  {
 			    $result .= '<option value="'.$value.'"';
-			    
+
 			    // Select current parent if it exists
 			    if ($one->Id() == $parent)
 			      {
@@ -915,11 +984,11 @@ class ContentOperations
 		{
 			return false;
 		}
-		
+
 		return $row['content_id'];
 	}
 
-	
+
 	/**
 	 * Returns the content id given a valid hierarchical position.
 	 *
@@ -1014,10 +1083,13 @@ class ContentOperations
 
 		return $error;
 	}
-	
+
 	/**
 	 * Clears the content cache
 	 *
+	 * @ignore
+         * @internal
+         * @access private
 	 * @return void
 	 */
 	function ClearCache()
@@ -1051,7 +1123,7 @@ class ContentOperations
 		#Change padded numbers back into user-friendly values
 		$tmp = '';
     $levels = preg_split('/\./', $position);
-    
+
 		foreach ($levels as $onelevel)
 		{
 			$tmp .= ltrim($onelevel, '0') . '.';
@@ -1071,9 +1143,9 @@ class ContentOperations
 	{
 		#Change user-friendly values into padded numbers
 		$tmp = '';
-        
+
     $levels = preg_split('/\./', $position);
-    
+
 		foreach ($levels as $onelevel)
 		{
 			$tmp .= str_pad($onelevel, 5, '0', STR_PAD_LEFT) . '.';
@@ -1108,6 +1180,16 @@ class ContentOperations
 			}
 		}
 	}
+
+	public function quickfind_node_by_id($id)
+	{
+		if( !is_array($this->_quickfind) ) {
+			$this->_quickfind = cmsms()->GetHierarchyManager()->getFlatList();
+			ksort($this->_quickfind);
+		}
+
+		if( isset($this->_quickfind[$id]) ) return $this->_quickfind[$id];
+	}
 }
 
 /**
