@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: listcontent.php 7396 2011-09-15 12:57:25Z rolf1 $
+#$Id: listcontent.php 9760 2014-11-14 19:15:01Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 require_once("../include.php");
@@ -33,6 +33,7 @@ define('XAJAX_DEFAULT_CHAR_ENCODING', $config['admin_encoding']);
 
 require_once(dirname(dirname(__FILE__)) . '/lib/xajax/xajax_core/xajax.inc.php');
 $xajax = new xajax();
+//$xajax->configure('requestURI',$config['admin_url'].'/listcontent.php?'.CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY]);
 $xajax->register(XAJAX_FUNCTION,'content_list_ajax');
 $xajax->register(XAJAX_FUNCTION,'content_setactive');
 $xajax->register(XAJAX_FUNCTION,'content_setinactive');
@@ -45,9 +46,22 @@ $xajax->register(XAJAX_FUNCTION,'content_delete');
 // $xajax->register(XAJAX_FUNCTION,'reorder_display_list');
 // $xajax->register(XAJAX_FUNCTION,'reorder_process');
 $xajax->processRequest();
-$headtext = $xajax->getJavascript($config['root_url'] . '/lib/xajax')."\n";
+$headtext = $xajax->getJavascript('../lib/xajax')."\n";
 include_once("header.php");
 
+function prettyurls_ok()
+{
+  static $_prettyurls_ok = -1;
+  if( -1 < $_prettyurls_ok ) return $_prettyurls_ok;
+
+  $config = cmsms()->GetConfig();
+  if( isset($config['url_rewriting']) && $config['url_rewriting'] != 'none' )
+    $_prettyurls_ok = 1;
+  else
+    $_prettyurls_ok = 0;
+  return $_prettyurls_ok;
+}
+
 function content_list_ajax()
 {
 	$objResponse = new xajaxResponse();
@@ -65,7 +79,7 @@ function setdefault($contentid)
 {
   $gCms = cmsms();
 	$userid = get_userid();
-	
+
 	$result = false;
 
 	if (check_permission($userid,'Manage All Content'))
@@ -85,7 +99,7 @@ function setdefault($contentid)
 				}
 			}
 		}
-		
+
 		$db = $gCms->GetDb();
 		$query = "SELECT content_id FROM ".cms_db_prefix()."content WHERE default_content=1";
 		$old_id = $db->GetOne($query);
@@ -102,7 +116,7 @@ function setdefault($contentid)
 				}
 			}
 		}
-		
+
 		$node = $hierManager->getNodeById($contentid);
 		if (isset($node))
 		{
@@ -114,6 +128,8 @@ function setdefault($contentid)
 			}
 		}
 
+		audit($contentid,'Core','Content item set as default');
+
 		$result = true;
 		$contentops = $gCms->GetContentOperations();
 		$contentops->ClearCache();
@@ -124,7 +140,7 @@ function setdefault($contentid)
 function content_setdefault($contentid)
 {
 	$objResponse = new xajaxResponse();
-	
+
 	setdefault($contentid);
 
 	$objResponse->assign("contentlist", "innerHTML", display_content_list());
@@ -135,7 +151,7 @@ function content_setdefault($contentid)
 function content_setactive($contentid)
 {
 	$objResponse = new xajaxResponse();
-	
+
 	setactive($contentid);
 
 	$objResponse->assign("contentlist", "innerHTML", display_content_list());
@@ -146,7 +162,7 @@ function content_setactive($contentid)
 function content_setinactive($contentid)
 {
 	$objResponse = new xajaxResponse();
-	
+
 	setactive($contentid, false);
 
 	$objResponse->assign("contentlist", "innerHTML", display_content_list());
@@ -157,7 +173,7 @@ function content_setinactive($contentid)
 function content_expandall()
 {
 	$objResponse = new xajaxResponse();
-	
+
 	expandall();
 
 	$objResponse->assign("contentlist", "innerHTML", display_content_list());
@@ -167,7 +183,7 @@ function content_expandall()
 function content_collapseall()
 {
 	$objResponse = new xajaxResponse();
-	
+
 	collapseall();
 
 	$objResponse->assign("contentlist", "innerHTML", display_content_list());
@@ -177,19 +193,22 @@ function content_collapseall()
 function expandall()
 {
 	$userid = get_userid();
-	$contentops = cmsms()->GetContentOperations();
-	$all = $contentops->GetAllContent(false);
-	$cs = '';
-	foreach ($all as $thisitem)
+	$hiermanager = cmsms()->GetHierarchyManager();
+
+	function _expandall_sub($node,&$list)
 	{
-	  if( is_object($thisitem) && $thisitem instanceof ContentBase )
-	    {
-		if ($thisitem->HasChildren())
-		{
-			$cs .= $thisitem->Id().'=1.';
-		}
+	  if( $node->has_children() ) {
+	    if( ($id = $node->get_tag('id')) > 0 ) $list[] = "$id=1";
+	    $children = $node->get_children();
+	    for( $i = 0; $i < count($children); $i++ ) {
+	      _expandall_sub($children[$i],$list);
 	    }
+	  }
 	}
+
+	$list = array();
+	_expandall_sub($hiermanager,$list);
+	$cs = implode('.',$list);
 	set_preference($userid, 'collapse', $cs);
 }
 
@@ -202,7 +221,7 @@ function collapseall()
 function content_toggleexpand($contentid, $collapse)
 {
 	$objResponse = new xajaxResponse();
-	
+
 	toggleexpand($contentid, $collapse=='true'?true:false);
 
 	$objResponse->assign("contentlist", "innerHTML", display_content_list());
@@ -213,7 +232,7 @@ function content_toggleexpand($contentid, $collapse)
 function content_delete($contentid)
 {
 	$objResponse = new xajaxResponse();
-	
+
 	deletecontent($contentid);
 
 	$objResponse->script("$('#tr_$contentid').effect('fade', [], 3000);");
@@ -257,9 +276,9 @@ function toggleexpand($contentid, $collapse = false)
 function setactive($contentid, $active = true)
 {
 	$userid = get_userid();
-	
+
 	$hierManager = cmsms()->GetHierarchyManager();
-	
+
 	// to activate a page, you must be admin, owner, or additional author
 	$permission = (	check_ownership($userid, $contentid) ||
 			check_authorship($userid, $contentid) ||
@@ -288,7 +307,7 @@ function content_move($contentid, $parentid, $direction)
       return $objResponse; // delay between requests
     }
   set_site_preference('__listcontent_timelock__',$time);
-	
+
 	movecontent($contentid, $parentid, $direction);
 
 	$objResponse->assign("contentlist", "innerHTML", display_content_list());
@@ -308,11 +327,11 @@ function movecontent($contentid, $parentid, $direction = 'down')
       (check_permission($userid, 'Reorder Content') && check_peer_authorship($userid,$contentid)) )
     {
       $order = 1;
-      
+
       // Grab necessary info for fixing the item_order
       $query = "SELECT item_order FROM ".cms_db_prefix()."content WHERE content_id = ?";
       $order = $db->GetOne($query, array($contentid));
-      
+
       $time = $db->DBTimeStamp(time());
       if ($direction == "down")
 	{
@@ -348,8 +367,9 @@ function deletecontent($contentid)
 	$access = (check_permission($userid, 'Remove Pages') &&
 	  (check_ownership($userid,$contentid) ||
 	   quick_check_authorship($contentid,$mypages)))
-	  || check_permission($userid, 'Manage All Content');
-	
+	  || check_permission($userid, 'Manage All Content')
+	  || check_permission($userid, 'Modify Any Page');
+
 	$gCms = cmsms();
 	$hierManager = $gCms->GetHierarchyManager();
 
@@ -358,13 +378,13 @@ function deletecontent($contentid)
 		$node = $hierManager->getNodeById($contentid);
 		if ($node)
 		{
-			$contentobj = $node->getContent(true);
+		        $contentobj = $node->getContent(true,false,true);
 			$childcount = 0;
 			$parentid = -1;
 			$parent = $node->getParent();
 			if ($parent)
 			{
-			  $parentContent = $parent->getContent();
+			  $parentContent = $parent->getContent(true,false,true);
 			  if (is_object($parentContent))
 			    {
 			      $parentid = $parentContent->Id();
@@ -375,40 +395,40 @@ function deletecontent($contentid)
 			if ($contentobj)
 			{
 				$title = $contentobj->Name();
-	
+
 				#Check for children
 				if ($contentobj->HasChildren())
 				{
 					$_GET['error'] = 'errorchildcontent';
 				}
-	
+
 				#Check for default
 				if ($contentobj->DefaultContent())
 				{
 					$_GET['error'] = 'errordefaultpage';
 				}
-			
+
 				$title = $contentobj->Name();
 				$contentobj->Delete();
 
 				$contentops = $gCms->GetContentOperations();
 				$contentops->SetAllHierarchyPositions();
-				
+
 				#See if this is the last child... if so, remove
 				#the expand for it
 				if ($childcount == 1 && $parentid > -1)
 				{
 					toggleexpand($parentid, true);
 				}
-				
+
 				#Do the same with this page as well
 				toggleexpand($contentid, true);
-				
+
 				// put mention into the admin log
-				audit($contentid, 'Content Item: '.$title, 'Deleted');
-				
+				audit($contentid, 'Core', 'Content Item: '.$title, 'Deleted');
+
 				$contentops->ClearCache();
-			
+
 				$_GET['message'] = 'contentdeleted';
 			}
 		}
@@ -431,7 +451,7 @@ function check_peer_authorship($userid,$contentid)
   $hm = cmsms()->GetHierarchyManager();
   $node = $hm->getNodeById($contentid);
   if( !$node ) return FALSE;
-  
+
   $parent = $node->getParentNode();
   if( !$node )
     {
@@ -486,9 +506,9 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
   global $config;
   global $page;
   global $indent;
-  
+
   if(empty($currow)) $currow = 'row1';
-  
+
   $children = $root->getChildren(false,true);
   $one = $root->getContent();
   $thelist = '';
@@ -498,13 +518,13 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
       audit($root->get_tag('id'),'Core','failed to get content for valid content id '.$root->get_tag('id'));
       return;
     }
-  
+
   if (!array_key_exists($one->Owner(), $users))
     {
       $userops = cmsms()->GetUserOperations();
       $users[$one->Owner()] = $userops->LoadUserById($one->Owner());
     }
-  
+
   $display = 'none';
   if (check_modify_all($userid) || check_ownership($userid, $one->Id()) || quick_check_authorship($one->Id(), $mypages))
     {
@@ -523,7 +543,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
   if ($display != 'none')
     {
       $thelist .= "<tr id=\"tr_".$one->Id()."\" class=\"$currow\">\n";
-      
+
       /* expand/collapse column */
       $columns['expand'] = '&nbsp;';
       if( $columnstodisplay['expand'] )
@@ -533,20 +553,20 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	    {
 	      if (!in_array($one->Id(),$openedArray))
 		{
-		  $txt .= "<a href=\"{$thisurl}&amp;content_id=".$one->Id()."&amp;col=0&amp;page=".$page."\" onclick=\"xajax_content_toggleexpand(".$one->Id().", 'false'); return false;\">";
+		  $txt .= "<a class=\"expand\" href=\"{$thisurl}&amp;content_id=".$one->Id()."&amp;col=0&amp;page=".$page."\" onclick=\"xajax_content_toggleexpand(".$one->Id().", 'false'); return false;\">";
 		  $txt .= $expandImg;
 		  $txt .= "</a>";
 		}
 	      else
 		{
-		  $txt .= "<a href=\"{$thisurl}&amp;content_id=".$one->Id()."&amp;col=1&amp;page=".$page."\" onclick=\"xajax_content_toggleexpand(".$one->Id().", 'true'); return false;\">";
+		  $txt .= "<a class=\"contract\" href=\"{$thisurl}&amp;content_id=".$one->Id()."&amp;col=1&amp;page=".$page."\" onclick=\"xajax_content_toggleexpand(".$one->Id().", 'true'); return false;\">";
 		  $txt .= $contractImg;
 		  $txt .= "</a>";
 		}
 	    }
 	  if( !empty($txt) ) $columns['expand'] = $txt;
 	}
-	  
+
 
       /* hierarchy column */
       if( $columnstodisplay['hier'] )
@@ -560,25 +580,23 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	{
 	  $columns['page'] = '&nbsp;';
 	  $txt = '';
-	  if( $one->MenuText() != CMS_CONTENT_HIDDEN_NAME )
-	    {
-	      if ($indent)
-		{
-		  for ($i=0;$i < $root->getLevel();$i++)
-		    {
-		      $txt .= "-&nbsp;&nbsp;&nbsp;";
-		    }
-		} 
+	  if( $one->MenuText() != CMS_CONTENT_HIDDEN_NAME ) {
+	      if ($indent) {
+              for ($i=0;$i < $root->getLevel();$i++) {
+                  $txt .= "-&nbsp;&nbsp;&nbsp;";
+              }
+          }
 	      $str = $one->MenuText();
-	      if( get_site_preference('listcontent_showtitle',0) )
-		{
-		  $str = $one->Name();
-		}
+
+	      if( get_site_preference('listcontent_showtitle',0) ) {
+              $str = $one->Name();
+          }
 	      if ($display == 'edit')
-		$txt .= '<a href="editcontent.php'.$urlext.'&amp;content_id='.$one->Id().'&amp;page='.$page.'" title="'. cms_htmlentities($one->Name().' ('.$one->Alias().')', '', '', true). '">' . cms_htmlentities($str, '', '', true) . '</a>';
+              $txt .= '<a class="tooltip" href="editcontent.php'.$urlext.'&amp;content_id='.$one->Id().'&amp;page='.$page.'" title="'. cms_htmlentities($one->Name().' ('.$one->Alias().')', '', '', true). '" onmouseover="document.getElementById(\'' .$one->Id().'_info\').style.display = \'inline-block\';" onmouseout="document.getElementById(\''.$one->Id().'_info\').style.display = \'none\';">
+			' . cms_htmlentities($str, '', '', true) . '<span id="'.$one->Id().'_info"><strong>'.lang('content_id').':</strong> '.$one->Id().'<br /> <strong>'.lang('title').':</strong> '. cms_htmlentities($one->Name()).'<br /> <strong>'.lang('pagealias').':</strong> '.$one->Alias().'</span></a>';
 	      else
-		$txt .= cms_htmlentities($str, '', '', true);
-	    }
+              $txt .= cms_htmlentities($str, '', '', true);
+      }
 	  if( !empty($txt) ) $columns['page'] = $txt;
 	}
 
@@ -587,13 +605,12 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	{
 	  $columns['alias'] = '&nbsp;';
 	  $txt = '';
-	  if( $one->HasUsableLink() && $one->Alias() != '' )
-	    {
+	  if( ($one->HasUsableLink() || $one->Type() == 'errorpage') && $one->Alias() != '' ) {
 	      $txt = $one->Alias();
-	    }
+      }
 	  if( !empty($txt) ) $columns['alias'] = $txt;
 	}
-       
+
       /* url column */
       if( $columnstodisplay['url'] )
 	{
@@ -608,6 +625,11 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 		}
 	      $txt = $url;
 	    }
+	  if( !empty($txt) ) {
+	    if( !prettyurls_ok() ) {
+	      $txt = '<span style="color: red;" title="'.lang('prettyurls_noeffect').'">'.$txt.'<span>';
+	    }
+	  }
 	  if( !empty($txt) ) $columns['url'] = $txt;
 	}
 
@@ -616,9 +638,9 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	{
 	  $columns['template'] = '&nbsp;';
 	  $txt = '';
-	  if( $one->Type() != 'pagelink' && 
-	      $one->Type() != 'link' && 
-	      $one->Type() != 'sectionheader' && 
+	  if( $one->Type() != 'pagelink' &&
+	      $one->Type() != 'link' &&
+	      $one->Type() != 'sectionheader' &&
 	      $one->Type() != 'separator' )
 	    {
 	      $template = TemplateOperations::get_instance()->LoadTemplateById($one->TemplateId());
@@ -710,7 +732,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	      if ($sameLevel>1)
 		{
 		  if (($one->ItemOrder() - 1) <= 0) #first
-		    { 
+		    {
 		      $txt .= "<a onclick=\"xajax_content_move(".$one->Id().", ".$one->ParentId().", 'down'); return false;\" href=\"{$thisurl}&amp;direction=down&amp;content_id=".$one->Id()."&amp;parent_id=".$one->ParentId()."&amp;page=".$page."\">";
 		      $txt .= $downImg;
 		      $txt .= "</a>&nbsp;&nbsp;";
@@ -730,7 +752,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 		      $txt .= "</a>";
 		    }
 		}
-	      
+
 	      // $txt .= '<input clsss="hidden" type="text" name="order-'. $one->Id().'" value="'.$one->ItemOrder().'" class="order" />';
 	    }
 	  if( !empty($txt) )
@@ -739,7 +761,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	    }
 	  // end of move code
 	}
-	
+
 
       /* view column */
       if( $columnstodisplay['view'] )
@@ -766,7 +788,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	{
 	  $columns['copy'] = '&nbsp;';
 	  $txt = '';
-	  if( $one->IsCopyable() && 
+	  if( $one->IsCopyable() &&
 	      ((check_permission($userid,'Add Pages') &&
 		(check_ownership($userid, $one->Id()) || quick_check_authorship($one->Id(), $mypages)))
 	       || check_permission($userid,'Manage All Content')) )
@@ -786,8 +808,8 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	{
 	  $columns['edit'] = '&nbsp;';
 	  $txt = '';
-	  if (check_modify_all($userid) || 
-	      check_ownership($userid, $one->Id()) || 
+	  if (check_modify_all($userid) ||
+	      check_ownership($userid, $one->Id()) ||
 	      quick_check_authorship($one->Id(), $mypages) ||
 	      check_permission($userid, 'Manage All Content'))
 	    {
@@ -810,11 +832,9 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	  $txt = '';
 	  if ($one->DefaultContent() != true)
 	    {
-	      if ($root->getChildrenCount() == 0 && 
+	      if ($root->getChildrenCount() == 0 &&
 		  ((check_permission($userid, 'Remove Pages') &&
-		    (check_ownership($userid,$one->Id()) || 
-		     quick_check_authorship($one->Id(),$mypages)))
-		   || check_permission($userid,'Manage All Content')) 
+		    (check_ownership($userid,$one->Id()) || quick_check_authorship($one->Id(),$mypages))) || check_permission($userid,'Manage All Content') || check_permission($userid,'Modify Any Page'))
 		 )
 		{
 		  //$txt .= "<a href=\"{$thisurl}&amp;deletecontent=".$one->Id()."\" onclick=\"confirm('".cms_html_entity_decode_utf8(lang('deleteconfirm', $one->mName), true)."');\">";
@@ -828,7 +848,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	      $columns['delete'] = $txt;
 	    }
 	}
-	    
+
       if( $columnstodisplay['multiselect'] )
 	{
 	  /* multiselect */
@@ -850,7 +870,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	      $columns['multiselect'] = $txt;
 	    }
 	}
-	  
+
       /* done */
       foreach( $columns as $name => $value )
 	{
@@ -866,7 +886,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	    case 'active':
 	      $thelist .= '<td class="pagepos">'.$value."</td>\n";
 	      break;
-	      
+
 	    case 'move':
 	      $thelist .= '<td class="move">'.$value."</td>\n";
 	      break;
@@ -874,7 +894,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	    case 'multiselect':
 	      $thelist .= '<td class="checkbox">'.$value."</td>\n";
 	      break;
-	      
+
 	    default:
 	      $thelist .= '<td>'.$value."</td>\n";
 	      break;
@@ -894,7 +914,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
       $author_allpages = check_permission($userid,'Reorder Content') && check_peer_authorship($userid,$children[0]->getId());
 
       foreach ($children as $child)
-        { 
+        {
 	  display_hierarchy($child, $userid, $modifyall, $users, $menupos, $openedArray, $pagelist, $image_true, $image_set_false, $image_set_true, $upImg, $downImg, $viewImg, $editImg, $copyImg, $deleteImg, $expandImg, $contractImg, $mypages, $page, $columnstodisplay, $author_allpages);
         }
     }
@@ -902,13 +922,13 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 
 function display_content_list($themeObject = null)
 {
-  $gCms = cmsms();
+        $gCms = cmsms();
 	global $thisurl;
 	global $urlext;
 
 	check_login();
 	$userid = get_userid();
-	
+
 	// setup which columns to display.
 	$mypages = author_pages($userid);
 	$columnstodisplay = array();
@@ -928,7 +948,7 @@ function display_content_list($themeObject = null)
 	$columnstodisplay['edit'] = 1;
 	$columnstodisplay['delete'] = check_permission($userid, 'Remove Pages') || check_permission($userid,'Manage All Content');
 	$columnstodisplay['multiselect'] = check_permission($userid, 'Remove Pages') || check_permission($userid,'Manage All Content');
-	
+
 	$page = 1;
 	if (isset($_GET['page']))
 		$page = $_GET['page'];
@@ -939,7 +959,7 @@ function display_content_list($themeObject = null)
 	$count = 0;
 
 	$currow = "row1";
-	
+
 	if ($themeObject == null)
 		$themeObject = AdminTheme::GetThemeObject();
 
@@ -963,7 +983,7 @@ function display_content_list($themeObject = null)
 	$users = array();
 
 	$menupos = array();
-	
+
 	$openedArray=array();
 	if (get_preference($userid, 'collapse', '') != '')
 	{
@@ -976,7 +996,7 @@ function display_content_list($themeObject = null)
 		}
 	}
 
-  debug_buffer('At Start of Display Content List');
+	debug_buffer('At Start of Display Content List');
         $hierarchy = $gCms->GetHierarchyManager();
 
 	$rowcount = 0;
@@ -988,7 +1008,7 @@ function display_content_list($themeObject = null)
 		$author_allpages = check_permission($userid,'Reorder Content') && check_peer_authorship($userid,$children[0]->getId());
 
 		foreach ($children as $child)
-		{ 
+		{
 		  display_hierarchy($child, $userid, check_modify_all($userid), $users, $menupos, $openedArray, $pagelist, $image_true, $image_set_false, $image_set_true, $upImg, $downImg, $viewImg, $editImg, $copyImg, $deleteImg, $expandImg, $contractImg, $mypages, $page, $columnstodisplay, $author_allpages );
 		}
 		$rowcount += count($pagelist);
@@ -1114,7 +1134,7 @@ function display_content_list($themeObject = null)
 	  {
 	    bulkcontentoperations::register_function(lang('delete'),'delete');
 	  }
-	if (check_permission($userid, 'Manage All Content')) 
+	if (check_permission($userid, 'Manage All Content'))
 	  {
 	    bulkcontentoperations::register_function(lang('active'),'active');
 	    bulkcontentoperations::register_function(lang('inactive'),'inactive');
@@ -1125,13 +1145,14 @@ function display_content_list($themeObject = null)
 	    bulkcontentoperations::register_function(lang('secure'),'secure');
 	    bulkcontentoperations::register_function(lang('insecure'),'insecure');
 	    bulkcontentoperations::register_function(lang('settemplate'),'settemplate');
+		bulkcontentoperations::register_function(lang('changeowner'),'changeowner');
 	  }
 	$opts = bulkcontentoperations::get_operation_list();
 	if( !empty($opts) )
 	  {
 	    echo '<div class="pageoptions">'."\n";
 	    echo '<div style="margin-top: 0; float: right; text-align: right">'."\n";
-	    echo '<label for="multiaction">'.lang('selecteditems').'</label>:&nbsp;&nbsp;'; 
+	    echo '<label for="multiaction">'.lang('selecteditems').'</label>:&nbsp;&nbsp;';
 	    echo '<select name="multiaction" id="multiaction">';
 	    foreach( $opts as $key => $value )
 	      {
@@ -1148,22 +1169,22 @@ function display_content_list($themeObject = null)
 	{
 ?>
 			<a href="addcontent.php<?php echo $urlext ?>" class="pageoptions">
-<?php 
+<?php
             echo $themeObject->DisplayImage('icons/system/newobject.gif', lang('addcontent'),'','','systemicon').'</a>';
             echo ' <a class="pageoptions" href="addcontent.php'.$urlext.'">'.lang("addcontent");
 ?>
 			</a>
-<?php 
-    } 
+<?php
+    }
 ?>
 		<a style="margin-left: 10px;" href="'.$thisurl.'&amp;expandall=1" onclick="xajax_content_expandall(); return false;">
-<?php 
+<?php
 			echo $themeObject->DisplayImage('icons/system/expandall.gif', lang('expandall'),'','','systemicon').'</a>';
 		echo ' <a class="pageoptions" href="'.$thisurl.'&amp;expandall=1" onclick="xajax_content_expandall(); return false;">'.lang("expandall");
 ?>
 			</a>&nbsp;&nbsp;&nbsp;
 		<a href="<?php echo $thisurl ?>&amp;collapseall=1" onclick="xajax_content_collapseall(); return false;">
-<?php 
+<?php
 			echo $themeObject->DisplayImage('icons/system/contractall.gif', lang('contractall'),'','','systemicon').'</a>';
 		echo ' <a class="pageoptions" href="'.$thisurl.'&amp;collapseall=1" onclick="xajax_content_collapseall(); return false;">'.lang("contractall").'</a>';
 		if (check_permission($userid, 'Manage All Content'))
@@ -1185,6 +1206,7 @@ function display_content_list($themeObject = null)
 	return $headoflist . $thelist . $footer .'</form></div>';
 }
 
+
 echo $themeObject->ShowMessage('', 'message');
 echo $themeObject->ShowErrors('' ,'error');
 ?>
@@ -1239,6 +1261,10 @@ if (isset($_GET['col']) && isset($_GET['content_id']))
 
 echo '<div class="pageoverflow">';
 echo $themeObject->ShowHeader('currentpages').'</div>';
+debug_buffer('test before loadallcontent');
+cmsms()->GetContentOperations()->LoadAllContent(FALSE,TRUE);
+
+debug_buffer('test after loadallcontent');
 echo '<div id="contentlist">'.display_content_list($themeObject).'</div>';
 
 ?>
@@ -1253,7 +1279,7 @@ echo '<div id="contentlist">'.display_content_list($themeObject).'</div>';
 		state = elem.checked;
 	        for (i=0; i<checkboxes.length ; i++)
 	        {
-	                if (checkboxes[i].type == "checkbox") 
+	                if (checkboxes[i].type == "checkbox")
 			  {
 			    checkboxes[i].checked=state;
 			  }
