@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: listmodules.php 7396 2011-09-15 12:57:25Z rolf1 $
+#$Id: listmodules.php 9229 2014-01-27 14:28:26Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 $CMS_PREVENT_AUTOINSTALL=1;
@@ -63,6 +63,7 @@ if ($access)
 		}
 		else
 		{
+		  audit('','Core','Changed permissions on '.$module.' directory');
 			redirect($thisurl);
 		}
 	}
@@ -74,8 +75,11 @@ if ($access)
 		$files = 0;
 		$old_display_errors = ini_set('display_errors',0);
 		$modops = $gCms->GetModuleOperations();
-		$object = cms_utils::get_module($module);
+		$orig_lang = CmsNlsOperations::get_current_language();
+		CmsNlsOperations::set_language('en_US');
+		$object = $modops->get_module_instance($module,'',TRUE);
 		$xmltxt = $modops->CreateXMLPackage($object,$message,$files);
+		CmsNlsOperations::set_language($orig_lang);
 		if( $files == 0 )
 		{
 			echo "<p class=\"error\">".lang('errornofilesexported')."</p>";
@@ -87,6 +91,7 @@ if ($access)
 		else 
 		{
 			$xmlname = $object->GetName().'-'.$object->GetVersion().'.xml';
+			audit('','Core','Exported '.$object->GetName().' to '.$xmlname);
 
 			// and send the file
 			ob_end_clean();
@@ -111,9 +116,9 @@ if ($access)
 		{
 			// normalize the file variable
 			$file = $_FILES[$fieldName];
-
-			// $file['tmp_name'] is the file we have to parse
-			// $xml = file_get_contents( $file['tmp_name'] );
+			if( !isset($file['tmp_name']) || trim($file['tmp_name']) == '' ) {
+			  echo $themeObject->ShowErrors(lang('noxmlfileuploaded').' (empty tmp_name)');
+			}
 
 			// and parse it
 			$modops = $gCms->GetModuleOperations();
@@ -155,6 +160,7 @@ if ($access)
 			    else if( $autoinstallupgrade == 0 )
 			      {
 				// no auto install or upgrade
+				audit('','Core','Expanded XML Package '.$file['name']);
 				redirect($thisurl);
 			      }
 			  }
@@ -171,7 +177,7 @@ if ($access)
 			echo '<p class="pageheader">'.lang('moduleerrormessage', $module).'</p>';					
 			echo $result[1];
 			echo "</div>";
-			echo '<p class="pageback"><a class="pageback" href="{$thisurl}">&#171; '.lang('back').'</a></p>';
+			echo '<p class="pageback"><a class="pageback" href="'.$thisurl.'">&#171; '.lang('back').'</a></p>';
 			include_once("footer.php");
 			exit;
 		}
@@ -244,7 +250,7 @@ if ($access)
 
 	if ($action == "uninstall")
 	{
-	  $modinstance = cms_utils::get_module($module);
+	  $modinstance = ModuleOperations::get_instance()->get_module_instance($module,'',TRUE);
 	  if( is_object($modinstance) )
 	    {
 	      $modops = $gCms->GetModuleOperations();
@@ -290,6 +296,7 @@ if ($access)
 	{
 		$query = "UPDATE ".cms_db_prefix()."modules SET active = ? WHERE module_name = ?";
 		$db->Execute($query, array(1,$module));
+		audit('','Core','Activated module '.$module);
 		cmsms()->clear_cached_files();
 		redirect($thisurl);
 	}
@@ -298,6 +305,7 @@ if ($access)
 	{
 		$query = "UPDATE ".cms_db_prefix()."modules SET active = ? WHERE module_name = ?";
 		$db->Execute($query, array(0,$module));
+		audit('','Core','Deactivated module '.$module);
 		cmsms()->clear_cached_files();
 		redirect($thisurl);
 	}
@@ -320,11 +328,11 @@ else if ($action == "showmodulehelp")
   $modinstance = ModuleOperations::get_instance()->get_module_instance($module,'',TRUE);
   if( is_object($modinstance) )
     {
-      $orig_lang =  cms_admin_current_language();
+      $orig_lang =  CmsNlsOperations::get_current_language();
       $modulehelp_yourlang = lang('modulehelp_yourlang');
       if( isset($_GET['lang']) && $orig_lang != 'en_US' )
 	{
-	  cms_set_admin_language(trim($_GET['lang']));
+	  CmsNlsOperations::set_language(trim($_GET['lang']));
 	}
 
       echo '<div class="pagecontainer">';
@@ -333,7 +341,6 @@ else if ($action == "showmodulehelp")
       
       $header  = '<div class="pageheader">';
       $header .= lang('modulehelp', array($module));
-      $wikiUrl = $config['wiki_url'];
       $module_name = $modinstance->GetName();
       // Turn ModuleName into _Module_Name
       $moduleName =  preg_replace('/([A-Z])/', "_$1", $module_name);
@@ -347,11 +354,10 @@ else if ($action == "showmodulehelp")
       // 		$dirname = dirname(__FILE__);
       // 		include($dirname.'/lang/en_US/admin.inc.php');
       $section = lang($modinstance->GetAdminSection());
-      $wikiUrl .= '/'.$section.'/'.$moduleName;
 
       if( $orig_lang != 'en_US' )
 	{
-	  $cur_lang = cms_admin_current_language();
+	  $cur_lang = CmsNlsOperations::get_current_language();
 	  if( $cur_lang == 'en_US' )
 	    {
 	      $header .= '<span class="helptext"><a href="listmodules.php?'.CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY].'&amp;action=showmodulehelp&amp;module='.$module.'&amp;lang='.$orig_lang.'">'.$modulehelp_yourlang.'</a></span>';
@@ -362,20 +368,6 @@ else if ($action == "showmodulehelp")
 	    }
 	}
 
-      //		if (FALSE == get_preference($userid, 'hide_help_links'))
-      if (FALSE)
-	{
-	  // Clean up URL
-	  $wikiUrl = str_replace(' ', '_', $wikiUrl);
-	  $wikiUrl = str_replace('&amp;', 'and', $wikiUrl);
-	  
-	  $help_title = lang('help_external');
-	  
-	  $image_help = $themeObject->DisplayImage('icons/system/info.gif', lang('help'),'','','systemicon');
-	  $image_help_external = $themeObject->DisplayImage('icons/system/info-external.gif', lang('help'),'','','systemicon');		
-	  $header .= '<span class="helptext"><a href="'.$wikiUrl.'" target="_blank">'.$image_help_external.'</a> <a href="'.$wikiUrl.'" target="_blank">'.lang('help').'</a> ('.lang('new_window').')</span>';
-	}
-      
       $header .= '</div>';
       echo $header;     
 
@@ -386,11 +378,11 @@ else if ($action == "showmodulehelp")
 	{
 	  $modinstance->curlang = trim($_GET['lang']);
 	}
-      echo $modinstance->GetHelpPage();
+      echo @$modinstance->GetHelpPage();
       $modinstance->params = array(array('name'=>'lang','default'=>'en_US','optional'=>true));
       $modinstance->curlang = $mod_old_lang;
       echo "</div>";
-      cms_set_admin_language($orig_lang);
+      CmsNlsOperations::set_language($orig_lang);
     }
   
   echo '<p class="pageback"><a class="pageback" href="'.$thisurl.'">&#171; '.lang('back').'</a></p>';
@@ -476,14 +468,15 @@ else
       <table cellspacing="0" class="pagetable">
 	 <thead>
 	 <tr>
-	 <th><?php echo lang('name')?></th>
-	 <th><?php echo lang('version')?></th>
-	 <th><?php echo lang('status')?></th>
+	 <th class="modname"><?php echo lang('name')?></th>
+	 <th class="modvers"><?php echo lang('version')?></th>
+	 <th class="modstatus"><?php echo lang('status')?></th>
 	 <th class="pagepos"><?php echo lang('active')?></th>
-	 <th><?php echo lang('action')?></th>
-	 <th><?php echo lang('help')?></th>
-	 <th><?php echo lang('about')?></th>
-	 <th><?php echo lang('export')?></th>
+	 <th class="modaction"><?php echo lang('action')?></th>
+	 <th class="modcachable"><?php echo lang('cachable')?></th>
+	 <th class="modhelp"><?php echo lang('help')?></th>
+	 <th class="modabout"><?php echo lang('about')?></th>
+	 <th class="modexport"><?php echo lang('export')?></th>
 	 </tr>
 	 </thead>
 	 <tbody>
@@ -497,6 +490,7 @@ else
       foreach($allmodules as $key)
 	{
 	  $modinstance = $modops->get_module_instance($key,'',true);
+	  if( !is_object($modinstance) ) continue; // interesting.
 	  $is_sysmodule = $modops->IsSystemModule($key);
 	  $namecol = $key;
 	  $versioncol = "&nbsp;";
@@ -507,11 +501,12 @@ else
 	  $helpcol = "&nbsp;";
 	  $aboutcol = "&nbsp;";	  
 	  $xmlcol = "&nbsp;";
+	  $cachablecol = '&nbsp;';
 
 	  $xmlcol = '<a href="'.$thisurl.'&amp;action=exportxml&amp;module='.$key.'"><img border="0" src="../modules/ModuleManager/images/xml_rss.gif" alt="'.lang('xml').'" /></a>';
 	  
 	  //Is there help?
-	  if ($modinstance->GetHelp() != '')
+	  if (@$modinstance->GetHelp() != '')
 	    {
 	      $namecol = "<a href=\"{$thisurl}&amp;action=showmodulehelp&amp;module=".$key."\">".$key."</a>";
 	    }
@@ -589,16 +584,15 @@ else
 	      $versioncol = $dbm[$key]['Version'];
 	      $statuscol[]  = '<span class="important">'.lang('needupgrade').'</span>';
 	      $activecol  = ($dbm[$key]['Active']==true?"<a href='{$thisurl}&amp;action=setfalse&amp;module=".$key."'>".$image_true."</a>":"<a href='{$thisurl}&amp;action=settrue&amp;module=".$key."'>".$image_false."</a>");
-	      if( $maxverok == 1)
-		{
-		  $actioncol[]  = "<a href=\"{$thisurl}&amp;action=upgrade&amp;module=".$key."\" onclick=\"return confirm('".cms_html_entity_decode_utf8(lang('upgradeconfirm'),true)."');\">".lang('upgrade')."</a>";
-		}
-	      $xmlcol = '&nbsp;';
+	      if( $maxverok == 1 && $dbm[$key]['Active'] == true) {
+		$actioncol[]  = "<a href=\"{$thisurl}&amp;action=upgrade&amp;module=".$key."\" onclick=\"return confirm('".cms_html_entity_decode_utf8(lang('upgradeconfirm'),true)."');\">".lang('upgrade')."</a>";
+	      }
 	    }
 	  else // Must be installed
 	    {
 	      $versioncol = $dbm[$key]['Version'];
 	      $statuscol[]  = lang('installed');
+	      $cachablecol = $modinstance->AllowSmartyCaching()?lang('yes'):lang('no');
 	      //$actioncol  = "&nbsp;";
 	      
 	      // Can't be removed if it has a dependency...
@@ -631,7 +625,7 @@ else
 	    }
 	  
 	  //Is there help?
-	  if ($modinstance->GetHelp() != '')
+	  if (@$modinstance->GetHelp() != '')
 	    {
 	      $helpcol = "<a href=\"{$thisurl}&amp;action=showmodulehelp&amp;module=".$key."\">".lang('help')."</a>";
 	    }
@@ -653,6 +647,7 @@ else
 	      echo '<td class="pagepos">'.$activecol.'</td>';
 	      echo '<td>'.implode('<br/>',$actioncol).'</td>';
 	    }
+	  echo "<td>$cachablecol</td>";
 	  echo "<td>$helpcol</td>";
 	  echo "<td>$aboutcol</td>";
 	  echo "<td>$xmlcol</td>";
